@@ -1,4 +1,4 @@
-/* Copyright (c) 2009, 2011, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2009, 2013, Oracle and/or its affiliates. All rights reserved.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -600,7 +600,7 @@
 #define WITH_MYISAMMRG_STORAGE_ENGINE 1
 #define WITH_HEAP_STORAGE_ENGINE 1
 #define WITH_INNOBASE_STORAGE_ENGINE 1
-/* #undef WITH_XTRADB_STORAGE_ENGINE */
+#define WITH_XTRADB_STORAGE_ENGINE 1
 #define WITH_CSV_STORAGE_ENGINE 1
 #define WITH_PARTITION_STORAGE_ENGINE 1
 #define WITH_PERFSCHEMA_STORAGE_ENGINE 1
@@ -618,24 +618,25 @@
 #define DEFAULT_CHARSET_HOME "/usr/local/mysql"
 #define PLUGINDIR "/usr/local/mysql/lib/plugin"
 /* #undef DEFAULT_SYSCONFDIR */
-/* #undef DEFAULT_TMPDIR */
+#define DEFAULT_TMPDIR P_tmpdir
 
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 0
-#define MYSQL_VERSION_PATCH 7
+#define MYSQL_VERSION_PATCH 10
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.0.7"
+#define PACKAGE_STRING "MySQL Server 10.0.10"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.0.7"
-#define VERSION "10.0.7"
+#define PACKAGE_VERSION "10.0.10"
+#define VERSION "10.0.10"
 #define PROTOCOL_VERSION 10
 
+#define MALLOC_LIBRARY "bundled jemalloc"
 
 /* time_t related defines */
 
